/**
 * PROXY Protocol Type Definitions
 * Based on HAProxy PROXY protocol specification
 */

/**
 * PROXY protocol version
 */
export type TProxyProtocolVersion = 'v1' | 'v2';

/**
 * Connection protocol type
 */
export type TProxyProtocol = 'TCP4' | 'TCP6' | 'UNKNOWN';

/**
 * Interface representing parsed PROXY protocol information
 */
export interface IProxyInfo {
  protocol: TProxyProtocol;
  sourceIP: string;
  sourcePort: number;
  destinationIP: string;
  destinationPort: number;
}

/**
 * Interface for parse result including remaining data
 */
export interface IProxyParseResult {
  proxyInfo: IProxyInfo | null;
  remainingData: Buffer;
}

/**
 * PROXY protocol v2 header format
 */
export interface IProxyV2Header {
  signature: Buffer;
  versionCommand: number;
  family: number;
  length: number;
}

/**
 * Connection information for PROXY protocol
 */
export interface IProxyConnectionInfo {
  sourceIp?: string;
  sourcePort?: number;
  destIp?: string;
  destPort?: number;
}